==> go.php?file=RaidSlackCheck1.251.zip: RaidSlackCheck/Localization/localization-zhCN.lua <==
﻿if GetLocale() == "zhCN" then

function rsclocalel()


	psfpotchecklocal = "药水检查"
	psfpotchecklocalt2 = "合剂检查"
	psfpotchecklocalt3 = "复活 - 重新Buff"
	psfpotchecklocalt322 = "战斗复活后检查Buff"
	rscaddonnotworkinz = "插件在以下区域启用："
	rscbuffnameslit1 = "王者祝福"
	rscbuffnameslit2 = "野性赐福"
	rscbuffnameslit3 = "耐力"
	rscbuffnameslit4 = "精神"
	rscbuffnameslit5 = "暗影防护"
	rscbuffnameslit6 = "智力"
	rscbuffnameslit7 = "智慧祝福"
	rscbuffnameslit8 = "力量祝福"
	rscbuffnameslit9 = "魔法增效"
	rscbuffspart1 = "此模块检查所选择的Buff"
	rscbuffspart2 = "战复后报告缺少哪些增益，并复查"
	rscbuffspart3 = "你可以设置BUFF的提供者，这样当他们在战斗中还存活的时候插件会密语他们补BUFF，否则就会密语所有能补BUFF的玩家"
	rscbuttonreset = "重置"
	rscbuttonztext1 = "添加当前区域"
	rscbuttonztext2 = "删除当前区域"
	rscbuttonztext3 = "显示列表"
	rscbuttonztext4 = "重置列表"
	rscchatlist1 = "团队"
	rscchatlist2 = "团队警告"
	rscchatlist3 = "官员"
	rscchatlist4 = "队伍"
	rscchatlist5 = "公会"
	rscchatlist6 = "说"
	rscchatlist7 = "大喊"
	rscchatlist8 = "自己"
	rscflasktext1 = "除了合剂和料理增益检查之外，该模块还可以自动检查以及自动公布结果(当战斗开始时或者使用Phoenixstyle开怪计时器时)"
	rscflasktext10 = "所有人已有合剂和食物Buff"
	rscflasktext11 = "所有人已喝合剂"
	rscflasktext12 = "无数据。许多人已死亡/离线。"
	rscflasktext1part2 = "忽略剩余持续时间小于|cffff0000%s|r 分钟的Buff"
	rscflasktext2 = "自动检查发布的频道"
	rscflasktext3 = "首先检查"
	rscflasktext4 = "只有一个药剂增益"
	rscflasktext5 = "无合剂"
	rscflasktext6 = "没有人拥有"
	rscflasktext7 = "无食物Buff"
	rscflasktext8 = "食物Buff仅有"
	rscflasktext9 = "未检查"
	rscflasktextc11 = "BOSS激活时通告"
	rscflasktextc12 = "当开怪计时条激活时通告"
	rscflasktextc13 = "就位确认时发布公告"
	rscflasktextc14 = "自动检查时发送密语"
	rscflasktextc15 = "检查食物"
	rscflasktxtgroup2 = "类型"
	rscflasktxtgroup5 = "类型"
	rscflaskwhisptxt1 = "RSC > 你没有食物Buff！"
	rscflaskwhisptxt11 = "RSC > 你的食物Buff即将到期。"
	rscflaskwhisptxt2 = "RSC > 你只有一个药剂效果！"
	rscflaskwhisptxt3 = "RSC > 你没有合剂或药剂效果！"
	rscflaskwhisptxt33 = "RSC > 你的合剂即将到期。"
	rscflaskwhisptxt4 = "RSC > 你没有食物Buff，并且只有一个药剂效果！"
	rscflaskwhisptxt40 = "RSC > 你没有食物Buff，并且合剂即将到期。"
	rscflaskwhisptxt44 = "RSC > 你的食物Buff即将到期，并且只有一个药剂效果！"
	rscflaskwhisptxt5 = "RSC > 你没有合剂和食物Buff！"
	rscflaskwhisptxt55 = "RSC > 你没有合剂效果，并且你的食物Buff即将到期！"
	rscflaskwhisptxt56 = "RSC > 你的合剂和食物Buff即将到期。"
	rsclocallpot = "全部药水"
	rscloccolor = "职业上色"
	rsclocfight1 = "最后一次战斗"
	rsclocfight2 = "上次战斗"
	rsclocfight3 = "战斗"
	rscloclastf = "最后一次战斗"
	rsclocnotinc = "脱离战斗"
	rsclocpot10 = "谁使用了药水"
	rsclocpot11 = "谁没使用药水"
	rsclocpot12 = "上次战斗前的药水"
	rsclocpot13 = "上次战斗前所使用的药水"
	rsclocpot14 = "上次战斗前没有人使用药水"
	rsclocpot15 = "在上场战斗开始之前使用的药剂"
	rsclocpot16 = "上场战斗中没有使用药剂:"
	rsclocpot17 = "没有人使用药水"
	rsclocpot18 = "使用过的药水"
	rsclocpot2 = "没有选择药剂"
	rsclocpot3 = "0药水"
	rsclocpot4 = "所有人使用了药水"
	rsclocpot5 = "相关信息"
	rsclocpot6 = "0药水"
	rsclocpot7 = "未检测到合剂"
	rsclocpot8 = "其他使用的药水："
	rsclocpot9 = "没有使用其他药水："
	rsclocrep1 = "发布到频道："
	rsclocrlslak = "发布RL合剂"
	rscmanualsend = "默认发送到"
	rscmin = "分钟"
	rsconlybossfig1 = "仅在首领战中检查药水使用情况"
	rsconlybossfig2 = "在任何战斗中都检查药水使用情况"
	rsconlybossfigtloc = "仅首领战"
	rscpartanons31 = "当1被选择时在聊天窗口通告"
	rscpartanons32 = "当2被选择时在聊天窗口通告"
	rscpartanons33 = "当1被选择时密语通告"
	rscpartanons34 = "当2被选择时密语通告"
	rscpartanons35 = "没有权限也发布公告"
	rscpartanons36 = "如果使用了合剂，检查2以及1"
	rscparton3 = "启用"
	rscpartwhobuff1 = "负责Buff："
	rscreleasedtxt1 = "被战复"
	rscreleasedtxt1f = "已战复"
	rscreleasedtxt2 = "前"
	rscreleasedtxt3 = "没有补上"
	rscreleasedtxt4 = "仍旧没有补上"
	rscreleasedtxt5 = "第二次检查"
	rscreleasedtxt6 = "但是仍旧没有补上"
	rscreleasedtxt6f = "但是仍旧没有补上"
	rscreleasedtxt7 = "但是没有补上"
	rscreleasedtxt7f = "但是没有补上"
	rscreloadbutton = "更新"
	rscsec = "秒。"
	rscsend = "更新并发送"
	rsczonereport1 = "在下列地区开启插件:"
	rsczonereport2 = "在下列地区运行插件:"
	rsczonereport3 = "在下列地区关闭插件:"
	rsczonereport5 = "列表空缺中，现在插件不会运行"
	rsczonereport6 = "列表空缺"
	rsczonereport7 = "|cffff0000Error!|r 当前区域已经在列表中！"
	rsczonereport8 = "|cffff0000Error!|r 当前区域未在列表中发现！"
	rsczonereport9 = "点此重置黑名单 |cffff0000TWICE|r"


end


end

==> go.php?file=RaidSlackCheck1.257.zip: RaidSlackCheck/Localization/localization-zhCN.lua <==
﻿if GetLocale() == "zhCN" then

function rsclocalel()


	psfpotchecklocal = "药水检查"
	psfpotchecklocalt2 = "合剂检查"
	psfpotchecklocalt3 = "复活 - 重新Buff"
	psfpotchecklocalt322 = "战斗复活后检查Buff"
	rscaddonnotworkinz = "插件在以下区域启用："
	rscbuffnameslitnew1 = "5% 全属性" -- Needs review
	rscbuffnameslitnew2 = "耐力"
	rscbuffnameslitnew3 = "暗影防护"
	rscbuffnameslitnew4 = "智力"
	rscbuffnameslitnew5 = "力量祝福" -- Needs review
	rscbuffspart1 = "此模块检查所选择的Buff"
	rscbuffspart2 = "战复后报告缺少哪些增益，并复查"
	rscbuffspart3 = "你可以设置BUFF的提供者，这样当他们在战斗中还存活的时候插件会密语他们补BUFF，否则就会密语所有能补BUFF的玩家"
	rscbuttonreset = "重置"
	rscbuttonztext1 = "添加当前区域"
	rscbuttonztext2 = "删除当前区域"
	rscbuttonztext3 = "显示列表"
	rscbuttonztext4 = "重置列表"
	rscchatlist1 = "团队"
	rscchatlist2 = "团队警告"
	rscchatlist3 = "官员"
	rscchatlist4 = "队伍"
	rscchatlist5 = "公会"
	rscchatlist6 = "说"
	rscchatlist7 = "大喊"
	rscchatlist8 = "自己"
	rscflasktext1 = "除了合剂和料理增益检查之外，该模块还可以自动检查以及自动公布结果(当战斗开始时或者使用Phoenixstyle开怪计时器时)"
	rscflasktext10 = "所有人已有合剂和食物Buff"
	rscflasktext11 = "所有人已喝合剂"
	rscflasktext12 = "无数据。许多人已死亡/离线。"
	rscflasktext1part2 = "忽略剩余持续时间小于|cffff0000%s|r 分钟的Buff"
	rscflasktext2 = "自动检查发布的频道"
	rscflasktext3 = "首先检查"
	rscflasktext4 = "只有一个药剂增益"
	rscflasktext5 = "无合剂"
	rscflasktext555 = "老式的合剂" -- Needs review
	rscflasktext6 = "没有人拥有"
	rscflasktext7 = "无食物Buff"
	rscflasktext8 = "食物Buff仅有"
	rscflasktext9 = "未检查"
	rscflasktextc11 = "BOSS激活时通告"
	rscflasktextc12 = "当开怪计时条激活时通告"
	rscflasktextc13 = "就位确认时发布公告"
	rscflasktextc14 = "自动检查时发送密语"
	rscflasktextc15 = "检查食物"
	rscflasktxtgroup2 = "类型"
	rscflasktxtgroup5 = "类型"
	rscflaskwhisptxt1 = "RSC > 你没有食物Buff！"
	rscflaskwhisptxt11 = "RSC > 你的食物Buff即将到期。"
	rscflaskwhisptxt2 = "RSC > 你只有一个药剂效果！"
	rscflaskwhisptxt3 = "RSC > 你没有合剂或药剂效果！"
	rscflaskwhisptxt33 = "RSC > 你的合剂即将到期。"
	rscflaskwhisptxt4 = "RSC > 你没有食物Buff，并且只有一个药剂效果！"
	rscflaskwhisptxt40 = "RSC > 你没有食物Buff，并且合剂即将到期。"
	rscflaskwhisptxt44 = "RSC > 你的食物Buff即将到期，并且只有一个药剂效果！"
	rscflaskwhisptxt5 = "RSC > 你没有合剂和食物Buff！"
	rscflaskwhisptxt55 = "RSC > 你没有合剂效果，并且你的食物Buff即将到期！"
	rscflaskwhisptxt56 = "RSC > 你的合剂和食物Buff即将到期。"
	rscfoodstillthere = "盛宴还在那里" -- Needs review
	rsclocallpot = "全部药水"
	rscloccolor = "职业上色"
	rsclocfight1 = "最后一次战斗"
	rsclocfight2 = "上次战斗"
	rsclocfight3 = "战斗"
	rscloclastf = "最后一次战斗"
	rsclocnotinc = "脱离战斗"
	rsclocpot10 = "谁使用了药水"
	rsclocpot11 = "谁没使用药水"
	rsclocpot12 = "上次战斗前的药水"
	rsclocpot13 = "上次战斗前所使用的药水"
	rsclocpot14 = "上次战斗前没有人使用药水"
	rsclocpot15 = "在上场战斗开始之前使用的药剂"
	rsclocpot16 = "上场战斗中没有使用药剂:"
	rsclocpot17 = "没有人使用药水"
	rsclocpot18 = "使用过的药水"
	rsclocpot2 = "没有选择药剂"
	rsclocpot3 = "0药水"
	rsclocpot4 = "所有人使用了药水"
	rsclocpot5 = "相关信息"
	rsclocpot6 = "0药水"
	rsclocpot7 = "未检测到合剂"
	rsclocpot8 = "其他使用的药水："
	rsclocpot9 = "没有使用其他药水："
	rsclocpoths17 = "没有人磕糖" -- Needs review
	rsclocpoths172 = "每个人都磕糖了" -- Needs review
	rsclocpoths18 = "磕过的糖" -- Needs review
	rsclocpoths182 = "没有磕糖" -- Needs review
	rsclocrep1 = "发布到频道："
	rsclocrlslak = "发布RL合剂"
	rscmanualsend = "默认发送到"
	rscmin = "分钟"
	rsconlybossfig1 = "仅在首领战中检查药水使用情况"
	rsconlybossfig2 = "在任何战斗中都检查药水使用情况"
	rsconlybossfigtloc = "仅首领战"
	rscpartanons31 = "当1被选择时在聊天窗口通告"
	rscpartanons32 = "当2被选择时在聊天窗口通告"
	rscpartanons33 = "当1被选择时密语通告"
	rscpartanons34 = "当2被选择时密语通告"
	rscpartanons35 = "没有权限也发布公告"
	rscpartanons36 = "如果使用了合剂，检查2以及1"
	rscparton3 = "启用"
	rscpartwhobuff1 = "负责Buff："
	rscreleasedtxt1 = "被战复"
	rscreleasedtxt1f = "已战复"
	rscreleasedtxt2 = "前"
	rscreleasedtxt3 = "没有补上"
	rscreleasedtxt4 = "仍旧没有补上"
	rscreleasedtxt5 = "第二次检查"
	rscreleasedtxt6 = "但是仍旧没有补上"
	rscreleasedtxt6f = "但是仍旧没有补上"
	rscreleasedtxt7 = "但是没有补上"
	rscreleasedtxt7f = "但是没有补上"
	rscreloadbutton = "更新"
	rscsec = "秒。"
	rscsend = "更新并发送"
	rsctablereptxt1 = "当有人放出盛宴时提示" -- Needs review
	rsctablereptxt2 = "当有人放出战斗大锅时提示" -- Needs review
	rsctablereptxt3 = "当有人召唤修理机器人时出现提示"
	rsctablereptxt4 = "当有人召唤灵魂之井时出现提示"
	rsctableused1 = "准备了一桌盛宴！" -- Needs review
	rsctableused2 = "准备了一个战斗大锅！" -- Needs review
	rsctableused3 = "召唤了修理机器人！"
	rsctableused4 = "正在召唤灵魂之井！"
	rscwhousehstext = "磕糖" -- Needs review
	rscwhousehstext2 = "没有磕糖" -- Needs review
	rsczonereport1 = "在下列地区开启插件:"
	rsczonereport2 = "在下列地区运行插件:"
	rsczonereport3 = "在下列地区关闭插件:"
	rsczonereport5 = "列表空缺中，现在插件不会运行"
	rsczonereport6 = "列表空缺"
	rsczonereport7 = "|cffff0000Error!|r 当前区域已经在列表中！"
	rsczonereport8 = "|cffff0000Error!|r 当前区域未在列表中发现！"
	rsczonereport9 = "点此重置黑名单 |cffff0000TWICE|r"


end


end
